/**
 * @packageDocumentation
 *
 * A peer discover mechanism that uses [mDNS](https://datatracker.ietf.org/doc/html/rfc6762) to discover peers on the local network.
 *
 * @example
 *
 * ```ts
 * import { mdns } from '@libp2p/mdns'
 *
 * const options = {
 *   peerDiscovery: [
 *     mdns()
 *   ]
 * }
 *
 * const libp2p = await createLibp2p(options)
 *
 * libp2p.on('peer:discovery', function (peerId) {
 *   console.log('found peer: ', peerId.toB58String())
 * })
 *
 * await libp2p.start()
 * ```
 *
 * ## MDNS messages
 *
 * A query is sent to discover the libp2p nodes on the local network
 *
 * ```js
 * {
 *    type: 'query',
 *    questions: [ { name: '_p2p._udp.local', type: 'PTR' } ]
 * }
 * ```
 *
 * When a query is detected, each libp2p node sends an answer about itself
 *
 * ```js
 * [{
 *   name: '_p2p._udp.local',
 *   type: 'PTR',
 *   class: 'IN',
 *   ttl: 120,
 *   data: 'QmNPubsDWATVngE3d5WDSNe7eVrFLuk38qb9t6vdLnu2aK._p2p._udp.local'
 * }, {
 *   name: 'QmNPubsDWATVngE3d5WDSNe7eVrFLuk38qb9t6vdLnu2aK._p2p._udp.local',
 *   type: 'SRV',
 *   class: 'IN',
 *   ttl: 120,
 *   data: {
 *     priority: 10,
 *     weight: 1,
 *     port: '20002',
 *     target: 'LAPTOP-G5LJ7VN9'
 *   }
 * }, {
 *   name: 'QmNPubsDWATVngE3d5WDSNe7eVrFLuk38qb9t6vdLnu2aK._p2p._udp.local',
 *   type: 'TXT',
 *   class: 'IN',
 *   ttl: 120,
 *   data: ['QmNPubsDWATVngE3d5WDSNe7eVrFLuk38qb9t6vdLnu2aK']
 * }, {
 *   name: 'LAPTOP-G5LJ7VN9',
 *   type: 'A',
 *   class: 'IN',
 *   ttl: 120,
 *   data: '127.0.0.1'
 * }, {
 *   name: 'LAPTOP-G5LJ7VN9',
 *   type: 'AAAA',
 *   class: 'IN',
 *   ttl: 120,
 *   data: '::1'
 * }]
 * ```
 */
import { MulticastDNS } from './mdns.js';
export function mdns(init = {}) {
    return (components) => new MulticastDNS(components, init);
}
/* for reference

   [ { name: '_p2p._udp.local',
       type: 'PTR',
       class: 1,
       ttl: 120,
       data: 'XQxZeAH6MX2n4255fzYmyUCUdhQ0DAWv.p2p._udp.local' },

     { name: 'XQxZeAH6MX2n4255fzYmyUCUdhQ0DAWv.p2p._udp.local',
       type: 'TXT',
       class: 1,
       ttl: 120,
       data: 'dnsaddr=/ip4/127.0.0.1/tcp/80/p2p/QmbBHw1Xx9pUpAbrVZUKTPL5Rsph5Q9GQhRvcWVBPFgGtC' },
]

*/
//# sourceMappingURL=index.js.map